@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_certificatemanager._jsii
@@ -25,9 +25,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-ecs-patterns",
-    "1.63.0",
+    "1.64.0",
     __name__[0:-6],
-    "aws-ecs-patterns@1.63.0.jsii.tgz",
+    "aws-ecs-patterns@1.64.0.jsii.tgz",
 )
 
 __all__ = [
